@@ -182,7 +182,7 @@ end
 end
 
 @inline function interpolate!(out1, out2, W::BoxWedgeTail, u, p, t)
-    if sign(W.dt) * t > sign(W.dt) * W.t[end] # Steps past W
+    return if sign(W.dt) * t > sign(W.dt) * W.t[end] # Steps past W
         dt = t - W.t[end]
         sample_distribution(W.dW, W, dt, u, p, t, W.rng)
         out1 .+= W.dW
@@ -234,10 +234,12 @@ end
 
 # joint probability density function
 function joint_density_function(r, a, rtol)
-    integral, err = QuadGK.quadgk(
+    integral,
+        err = QuadGK.quadgk(
         x -> r / π * (x / sinh(x)) *
-             exp(-r^2 * x / (2 * tanh(x))) * cos(a * x), 0, Inf,
-        rtol = rtol)
+            exp(-r^2 * x / (2 * tanh(x))) * cos(a * x), 0, Inf,
+        rtol = rtol
+    )
     return integral
 end
 
@@ -288,8 +290,10 @@ function generate_boxes1(densf, Δr, Δa, Δz, rM, aM, offset = nothing, scale =
             counter = 0
 
             # check for complete inclusion of box in volume
-            while (z <= densf(r, a) && z <= densf(r + Δr, a) && z <= densf(r, a + Δa) &&
-                   z <= densf(r + Δr, a + Δa))
+            while (
+                    z <= densf(r, a) && z <= densf(r + Δr, a) && z <= densf(r, a + Δa) &&
+                        z <= densf(r + Δr, a + Δa)
+                )
                 counter += one(counter)
                 z += Δz
             end
@@ -308,8 +312,10 @@ function generate_boxes1(densf, Δr, Δa, Δz, rM, aM, offset = nothing, scale =
     return boxes, probability, offset
 end
 
-function generate_boxes2(densf, Δrmin, Δamin, Δzmin, Δrmax, Δamax, Δzmax, rM, aM,
-        offset = nothing)
+function generate_boxes2(
+        densf, Δrmin, Δamin, Δzmin, Δrmax, Δamax, Δzmax, rM, aM,
+        offset = nothing
+    )
     boxes = Array{typeof(Δrmin), 1}[]
     probability = Vector{typeof(Δrmin)}(undef, 0)
     # start with largest possible size, then subsequently decrease size and fill remaining space
@@ -354,8 +360,10 @@ function generate_boxes3(densf, Δr, Δa, Δz, rM, aM, offset = nothing, scale =
                 z += offset[indx1, indx2]
             end
             # check for complete inclusion of box in volume
-            while (z <= densf(r, a) && z <= densf(r + Δr, a) && z <= densf(r, a + Δa) &&
-                   z <= densf(r + Δr, a + Δa))
+            while (
+                    z <= densf(r, a) && z <= densf(r + Δr, a) && z <= densf(r, a + Δa) &&
+                        z <= densf(r + Δr, a + Δa)
+                )
                 # store position of top corner of box and width
                 push!(boxes, [r, a, Δr, Δa])
                 # probability = 2*Δr*Δa*Δz for all small boxes, push!(probability, 1)
@@ -384,8 +392,12 @@ function sample_box(W::BoxWedgeTail, Boxes::AbstractBoxGeneration)
     indx = rand(W.rng, Boxes.dist)
     # boxes store r, a, Δr, Δa
     ri, ai, Δr, Δa = Boxes.boxes[indx]
-    DU = Distributions.product_distribution(Distributions.Uniform.([ri, ai],
-        [ri + Δr, ai + Δa]))
+    DU = Distributions.product_distribution(
+        Distributions.Uniform.(
+            [ri, ai],
+            [ri + Δr, ai + Δa]
+        )
+    )
 
     r, a = rand(W.rng, DU)
     return r, a
@@ -404,19 +416,23 @@ function linear_interpolation_wedges(fij, fij2, fij3, fij4, r, a, ri, ai, Δr, 
     t = (r - ri) / Δr
     u = (a - ai) / Δa
     return (one(t) - t) * (one(u) - u) * fij + t * (one(u) - u) * fij2 +
-           (one(t) - t) * u * fij3 + t * u * fij4
+        (one(t) - t) * u * fij3 + t * u * fij4
 end
 
-function constrained_optimization_problem(densf, fij, fij2, fij3, fij4, ri, ai, Δr, Δa)
-    function difference(x)
-        densf(x[1], x[2]) -
-        linear_interpolation_wedges(fij, fij2, fij3, fij4, x[1], x[2], ri, ai, Δr, Δa)
+# Stub for Optim-based constrained optimization (implemented in extension)
+function constrained_optimization_problem end
+
+# Error hint for when Optim extension is not loaded
+function __init__()
+    if isdefined(Base.Experimental, :register_error_hint)
+        Base.Experimental.register_error_hint(MethodError) do io, exc, argtypes, kwargs
+            if exc.f === constrained_optimization_problem
+                print(io, "\nUsing BoxWedgeTail with `sqeezing=true` requires Optim.jl. ")
+                print(io, "Please load Optim with `using Optim` before using this feature.")
+            end
+        end
     end
-    ϵijmax = Optim.optimize(x -> -difference(x), [ri, ai], [ri + Δr, ai + Δa],
-        [ri + Δr / 2, ai + Δa / 2], Optim.Fminbox(Optim.NelderMead()))
-    ϵijmin = Optim.optimize(x -> difference(x), [ri, ai], [ri + Δr, ai + Δa],
-        [ri + Δr / 2, ai + Δa / 2], Optim.Fminbox(Optim.NelderMead()))
-    return ϵijmin.minimum, ϵijmax.minimum
+    return nothing
 end
 
 function generate_wedges(densf, Δr, Δa, Δz, rM, aM, offset, sqeezing)
@@ -439,8 +455,11 @@ function generate_wedges(densf, Δr, Δa, Δz, rM, aM, offset, sqeezing)
 
             # store position of top corner of box and width
             if sqeezing
-                ϵijmin, ϵijmax = constrained_optimization_problem(densf, fij, fij2, fij3,
-                    fij4, r, a, Δr, Δa)
+                ϵijmin,
+                    ϵijmax = constrained_optimization_problem(
+                    densf, fij, fij2, fij3,
+                    fij4, r, a, Δr, Δa
+                )
                 push!(boxes, [f̃ij, hij, abs(ϵijmin), abs(ϵijmax), r, a])
                 # store PDF values
                 push!(f, [fij, fij2, fij3, fij4])
@@ -460,18 +479,24 @@ function sample_wedge(W::BoxWedgeTail, wedges::Wedges)
     indx = rand(W.rng, wedges.dist)
     # wedges store f̃ij, hij, ϵijmin, ϵijmax, r, a, Δr
     f̃ij, hij, ϵijmin, ϵijmax, ri, ai = wedges.boxes[indx]
-    DU = Distributions.product_distribution(Distributions.Uniform.([ri, ai, hij],
-        [
-            ri + W.Δr,
-            ai + W.Δa,
-            f̃ij
-        ]))
+    DU = Distributions.product_distribution(
+        Distributions.Uniform.(
+            [ri, ai, hij],
+            [
+                ri + W.Δr,
+                ai + W.Δa,
+                f̃ij,
+            ]
+        )
+    )
     if W.sqeezing
         fij, fij2, fij3, fij4 = wedges.fvalues[indx]
         while true
             r, a, z = rand(W.rng, DU)
-            flin = linear_interpolation_wedges(fij, fij2, fij3, fij4, r, a, ri, ai, W.Δr,
-                W.Δa)
+            flin = linear_interpolation_wedges(
+                fij, fij2, fij3, fij4, r, a, ri, ai, W.Δr,
+                W.Δa
+            )
             if z > flin + ϵijmax
                 continue
             elseif z < flin - ϵijmin
@@ -503,15 +528,17 @@ struct Tail1{pType, distType, pdfType, cType} <: AbstractTail
     function Tail1(rM, aM)
         p = convert(typeof(rM), 0.0002982405821953734)
         candpdf = (r, a) -> exp(-r^2 / 2)
-        dist1 = Distributions.truncated(Distributions.Normal(zero(rM), one(rM)), rM,
-            12 * one(rM))
+        dist1 = Distributions.truncated(
+            Distributions.Normal(zero(rM), one(rM)), rM,
+            12 * one(rM)
+        )
         dist2 = Distributions.Uniform(zero(aM), aM)
 
         dist = Distributions.product_distribution([dist1, dist2])
 
         c = convert(typeof(rM), 2.3)
 
-        new{typeof(p), typeof(dist), typeof(candpdf), typeof(c)}(p, dist, candpdf, c)
+        return new{typeof(p), typeof(dist), typeof(candpdf), typeof(c)}(p, dist, candpdf, c)
     end
 end
 
@@ -527,18 +554,22 @@ struct Tail2{pType, distType, pdfType, cType, boundsType} <: AbstractTail
         p = convert(typeof(rM), 3.648002197730662e-5)
         candpdf = (r, a) -> 3 // 2 * exp(-r^2 / 2 - 3 * a^2 / (2 * r^2))
         # store only distribution of r, when sampling re-create distribution for a|r
-        dist = Distributions.truncated(Distributions.Normal(zero(rM), one(rM)), rM,
-            8 * one(rM))
+        dist = Distributions.truncated(
+            Distributions.Normal(zero(rM), one(rM)), rM,
+            8 * one(rM)
+        )
 
         c = convert(typeof(rM), 2.0)
 
         alower = aM
         aupper = 2 * aM
 
-        new{typeof(p), typeof(dist), typeof(candpdf), typeof(c), typeof(alower)}(p, dist,
+        return new{typeof(p), typeof(dist), typeof(candpdf), typeof(c), typeof(alower)}(
+            p, dist,
             candpdf, c,
             alower,
-            aupper)
+            aupper
+        )
     end
 end
 
@@ -553,15 +584,20 @@ struct Tail3{pType, distType, pdfType, cType} <: AbstractTail
         candpdf = (r, a) -> exp(convert(typeof(rM), -pi / 2) * a)
         dist1 = Distributions.Uniform(2 * one(rM), rM)
         dist2 = Distributions.truncated(
-            Distributions.Exponential(convert(typeof(rM),
-                2 / pi)), aM,
-            8 * one(aM))
+            Distributions.Exponential(
+                convert(
+                    typeof(rM),
+                    2 / pi
+                )
+            ), aM,
+            8 * one(aM)
+        )
 
         dist = Distributions.product_distribution([dist1, dist2])
 
         c = convert(typeof(rM), 2.6)
 
-        new{typeof(p), typeof(dist), typeof(candpdf), typeof(c)}(p, dist, candpdf, c)
+        return new{typeof(p), typeof(dist), typeof(candpdf), typeof(c)}(p, dist, candpdf, c)
     end
 end
 
@@ -576,15 +612,20 @@ struct Tail4{pType, distType, pdfType, cType} <: AbstractTail
         candpdf = (r, a) -> 15 * r * exp(convert(typeof(rM), -pi) * a)
         dist1 = Distributions.TriangularDist(zero(rM), one(rM) / 2, one(rM) / 2)
         dist2 = Distributions.truncated(
-            Distributions.Exponential(convert(typeof(rM),
-                1 / pi)), aM,
-            6 * one(aM))
+            Distributions.Exponential(
+                convert(
+                    typeof(rM),
+                    1 / pi
+                )
+            ), aM,
+            6 * one(aM)
+        )
 
         dist = Distributions.product_distribution([dist1, dist2])
 
         c = convert(typeof(rM), 2.6)
 
-        new{typeof(p), typeof(dist), typeof(candpdf), typeof(c)}(p, dist, candpdf, c)
+        return new{typeof(p), typeof(dist), typeof(candpdf), typeof(c)}(p, dist, candpdf, c)
     end
 end
 
@@ -599,15 +640,20 @@ struct Tail5{pType, distType, pdfType, cType} <: AbstractTail
         candpdf = (r, a) -> 15 * r * exp(convert(typeof(rM), -2.8) * a)
         dist1 = Distributions.TriangularDist(one(rM) / 2, one(rM), one(rM))
         dist2 = Distributions.truncated(
-            Distributions.Exponential(convert(typeof(rM),
-                1 / 2.8)), aM,
-            6 * one(aM))
+            Distributions.Exponential(
+                convert(
+                    typeof(rM),
+                    1 / 2.8
+                )
+            ), aM,
+            6 * one(aM)
+        )
 
         dist = Distributions.product_distribution([dist1, dist2])
 
         c = convert(typeof(rM), 2.8)
 
-        new{typeof(p), typeof(dist), typeof(candpdf), typeof(c)}(p, dist, candpdf, c)
+        return new{typeof(p), typeof(dist), typeof(candpdf), typeof(c)}(p, dist, candpdf, c)
     end
 end
 
@@ -622,15 +668,20 @@ struct Tail6{pType, distType, pdfType, cType} <: AbstractTail
         candpdf = (r, a) -> 25 * r * exp(convert(typeof(rM), -2.6) * a)
         dist1 = Distributions.TriangularDist(one(rM), 3 / 2 * one(rM), 3 / 2 * one(rM))
         dist2 = Distributions.truncated(
-            Distributions.Exponential(convert(typeof(rM),
-                1 / 2.6)), aM,
-            6 * one(aM))
+            Distributions.Exponential(
+                convert(
+                    typeof(rM),
+                    1 / 2.6
+                )
+            ), aM,
+            6 * one(aM)
+        )
 
         dist = Distributions.product_distribution([dist1, dist2])
 
         c = convert(typeof(rM), 3.0)
 
-        new{typeof(p), typeof(dist), typeof(candpdf), typeof(c)}(p, dist, candpdf, c)
+        return new{typeof(p), typeof(dist), typeof(candpdf), typeof(c)}(p, dist, candpdf, c)
     end
 end
 
@@ -645,15 +696,20 @@ struct Tail7{pType, distType, pdfType, cType} <: AbstractTail
         candpdf = (r, a) -> 25 * r * exp(convert(typeof(rM), -2.4) * a)
         dist1 = Distributions.TriangularDist(3 / 2 * one(rM), 2 * one(rM), 2 * one(rM))
         dist2 = Distributions.truncated(
-            Distributions.Exponential(convert(typeof(rM),
-                1 / 2.4)), aM,
-            6 * one(aM))
+            Distributions.Exponential(
+                convert(
+                    typeof(rM),
+                    1 / 2.4
+                )
+            ), aM,
+            6 * one(aM)
+        )
 
         dist = Distributions.product_distribution([dist1, dist2])
 
         c = convert(typeof(rM), 3.2)
 
-        new{typeof(p), typeof(dist), typeof(candpdf), typeof(c)}(p, dist, candpdf, c)
+        return new{typeof(p), typeof(dist), typeof(candpdf), typeof(c)}(p, dist, candpdf, c)
     end
 end
 
@@ -668,15 +724,20 @@ struct Tail8{pType, distType, pdfType, cType} <: AbstractTail
         candpdf = (r, a) -> 40 * r * exp(convert(typeof(rM), -2.4) * a)
         dist1 = Distributions.TriangularDist(one(rM), 2 * one(rM), 2 * one(rM))
         dist2 = Distributions.truncated(
-            Distributions.Exponential(convert(typeof(rM),
-                1 / 2.4)),
-            6 * one(aM), 8 * one(aM))
+            Distributions.Exponential(
+                convert(
+                    typeof(rM),
+                    1 / 2.4
+                )
+            ),
+            6 * one(aM), 8 * one(aM)
+        )
 
         dist = Distributions.product_distribution([dist1, dist2])
 
         c = convert(typeof(rM), 4.2)
 
-        new{typeof(p), typeof(dist), typeof(candpdf), typeof(c)}(p, dist, candpdf, c)
+        return new{typeof(p), typeof(dist), typeof(candpdf), typeof(c)}(p, dist, candpdf, c)
     end
 end
 
@@ -691,21 +752,28 @@ struct Tail9{pType, distType, pdfType, cType} <: AbstractTail
         candpdf = (r, a) -> 7 // 10 * exp(convert(typeof(rM), -pi / 2) * a)
         dist1 = Distributions.Uniform(2 * one(rM), 5 * one(rM))
         dist2 = Distributions.truncated(
-            Distributions.Exponential(convert(typeof(rM),
-                2 / pi)),
-            8 * one(aM), 10 * one(aM))
+            Distributions.Exponential(
+                convert(
+                    typeof(rM),
+                    2 / pi
+                )
+            ),
+            8 * one(aM), 10 * one(aM)
+        )
 
         dist = Distributions.product_distribution([dist1, dist2])
 
         c = convert(typeof(rM), 2.4)
 
-        new{typeof(p), typeof(dist), typeof(candpdf), typeof(c)}(p, dist, candpdf, c)
+        return new{typeof(p), typeof(dist), typeof(candpdf), typeof(c)}(p, dist, candpdf, c)
     end
 end
 
-struct TailApproxs{T1 <: Tail1, T2 <: Tail2, T3 <: Tail3, T4 <: Tail4, T5 <: Tail5,
-    T6 <: Tail6,
-    T7 <: Tail7, T8 <: Tail8, T9 <: Tail9, distType}
+struct TailApproxs{
+        T1 <: Tail1, T2 <: Tail2, T3 <: Tail3, T4 <: Tail4, T5 <: Tail5,
+        T6 <: Tail6,
+        T7 <: Tail7, T8 <: Tail8, T9 <: Tail9, distType,
+    }
     tail1::T1
     tail2::T2
     tail3::T3
@@ -737,13 +805,15 @@ struct TailApproxs{T1 <: Tail1, T2 <: Tail2, T3 <: Tail3, T4 <: Tail4, T5 <: Tai
             tail6.p,
             tail7.p,
             tail8.p,
-            tail9.p
+            tail9.p,
         ]
 
         dist = Distributions.Categorical(probability / sum(probability))
 
-        new{typeof(tail1), typeof(tail2), typeof(tail3), typeof(tail4), typeof(tail5),
-            typeof(tail6), typeof(tail7), typeof(tail8), typeof(tail9), typeof(dist)}(
+        return new{
+            typeof(tail1), typeof(tail2), typeof(tail3), typeof(tail4), typeof(tail5),
+            typeof(tail6), typeof(tail7), typeof(tail8), typeof(tail9), typeof(dist),
+        }(
             tail1,
             tail2,
             tail3,
@@ -753,7 +823,8 @@ struct TailApproxs{T1 <: Tail1, T2 <: Tail2, T3 <: Tail3, T4 <: Tail4, T5 <: Tai
             tail7,
             tail8,
             tail9,
-            dist)
+            dist
+        )
     end
 end
 
@@ -781,7 +852,7 @@ function sample_tail(W::BoxWedgeTail, tails::TailApproxs)
         T = tails.tail9
     end
 
-    r, a = sample_tail(W.rng, W.jpdf, T)
+    return r, a = sample_tail(W.rng, W.jpdf, T)
 end
 
 function sample_tail(rng, densf, T::Tail2)
@@ -794,8 +865,10 @@ function sample_tail(rng, densf, T::Tail2)
         # draw first the r value
         r = rand(rng, T.dist)
         # generate a from the conditional distribution
-        dista = Distributions.truncated(Distributions.Normal(zero(r), sqrt(r / 3)),
-            T.alower, T.aupper)
+        dista = Distributions.truncated(
+            Distributions.Normal(zero(r), sqrt(r / 3)),
+            T.alower, T.aupper
+        )
         a = rand(rng, dista)
         if U <= densf(r, a) / (T.cvalue * T.candpdf(r, a))
             break
