@@ -1,3 +1,9 @@
+"""
+    save_noise!(W::NoiseProcess)
+
+Save the current noise value and time to the process history if it hasn't been saved already.
+This function is called automatically by the stepping algorithms to maintain the noise trajectory.
+"""
 @inline function save_noise!(W::NoiseProcess)
     if W.t != W.curt
         push!(W.W, copy(W.curW))
@@ -9,6 +15,19 @@
     return nothing
 end
 
+"""
+    accept_step!(W::NoiseProcess, dt, u, p, setup_next = true)
+
+Accept a noise step, updating the current time and noise values.
+This function is called by the SDE solvers after a successful integration step.
+
+## Arguments
+- `W`: The noise process
+- `dt`: Time step size (may differ from W.dt due to adaptivity)
+- `u`: Current solution value (for state-dependent noise)
+- `p`: Parameters (for state-dependent noise)
+- `setup_next`: Whether to prepare for the next step
+"""
 @inline function accept_step!(W::NoiseProcess, dt, u, p, setup_next = true)
     W.curt += W.dt
     W.iter += 1
@@ -41,6 +60,25 @@ end
     return nothing
 end
 
+"""
+    setup_next_step!(W::NoiseProcess, u, p)
+
+Prepare the noise process for the next integration step.
+
+This function manages the Rejection Sampling with Memory (RSWM) algorithm,
+handling the stacks of pre-computed noise values for adaptive time stepping.
+
+# Arguments
+- `W`: The noise process
+- `u`: Current solution value (for state-dependent noise)
+- `p`: Parameters (for state-dependent noise)
+
+# Details
+The function implements different variants of the RSWM algorithm:
+- RSwM1: Basic rejection sampling
+- RSwM2: Improved version with better memory management
+- RSwM3: Most advanced version with two-stack system
+"""
 @inline function setup_next_step!(W::NoiseProcess, u, p)
     if adaptive_alg(W) == :RSwM3
         ResettableStacks.reset!(W.S₂) #Empty W.S₂
@@ -97,8 +135,10 @@ end
                 else
                     W.dWtilde = W.bridge(W.dW, W, W.curW, L₂, qtmp, L₁, u, p, W.curt, W.rng)
                     if W.Z !== nothing
-                        W.dZtilde = W.bridge(W.dZ, W, W.curZ, L₃, qtmp, L₁, u, p, W.curt,
-                            W.rng)
+                        W.dZtilde = W.bridge(
+                            W.dZ, W, W.curZ, L₃, qtmp, L₁, u, p, W.curt,
+                            W.rng
+                        )
                     end
                 end
                 if isinplace(W)
@@ -131,13 +171,21 @@ end
                     end
                     if adaptive_alg(W) == :RSwM3 && qtmp * L₁ > W.rswm.discard_length
                         if W.Z == nothing
-                            ResettableStacks.copyat_or_push!(W.S₂,
-                                (qtmp * L₁, W.dWtilde,
-                                    nothing))
+                            ResettableStacks.copyat_or_push!(
+                                W.S₂,
+                                (
+                                    qtmp * L₁, W.dWtilde,
+                                    nothing,
+                                )
+                            )
                         else
-                            ResettableStacks.copyat_or_push!(W.S₂,
-                                (qtmp * L₁, W.dWtilde,
-                                    W.dZtilde))
+                            ResettableStacks.copyat_or_push!(
+                                W.S₂,
+                                (
+                                    qtmp * L₁, W.dWtilde,
+                                    W.dZtilde,
+                                )
+                            )
                         end
                     end
                 end
@@ -181,6 +229,23 @@ end
     return nothing
 end
 
+"""
+    calculate_step!(W::NoiseProcess, dt, u, p)
+
+Calculate noise increments for the given time step.
+
+This function generates new random values for the noise process according
+to its distribution function.
+
+# Arguments
+- `W`: The noise process
+- `dt`: Time step size
+- `u`: Current solution value (for state-dependent noise)
+- `p`: Parameters (for state-dependent noise)
+
+# Effects
+Updates W.dW (and W.dZ if auxiliary process exists) with new noise increments
+"""
 @inline function calculate_step!(W::NoiseProcess, dt, u, p)
     if isinplace(W)
         W.dist(W.dW, W, dt, u, p, W.curt, W.rng)
@@ -197,10 +262,29 @@ end
     return nothing
 end
 
+"""
+    reject_step!(W::NoiseProcess, dtnew, u, p)
+
+Handle rejection of a time step in adaptive algorithms.
+
+When an adaptive SDE solver rejects a step, this function uses bridge
+interpolation to generate appropriate noise values for the smaller time step,
+maintaining distributional correctness.
+
+# Arguments
+- `W`: The noise process
+- `dtnew`: New (smaller) time step after rejection
+- `u`: Current solution value (for state-dependent noise)
+- `p`: Parameters (for state-dependent noise)
+
+# Details
+The function stores unused portions of noise in the RSWM stacks for later use,
+ensuring the noise process remains distributionally exact despite adaptivity.
+"""
 @inline function reject_step!(W::NoiseProcess, dtnew, u, p)
     q = dtnew / W.dt
     if adaptive_alg(W) == :RSwM1 || adaptive_alg(W) == :RSwM2 ||
-       (adaptive_alg(W) == :RSwM3 && isempty(W.S₂))
+            (adaptive_alg(W) == :RSwM3 && isempty(W.S₂))
         if isinplace(W)
             W.bridge(W.dWtilde, W, 0, W.dW, q, dtnew, u, p, W.curt, W.rng)
             if W.Z !== nothing
@@ -337,7 +421,7 @@ end
 
 @inline function interpolate!(W::NoiseProcess, u, p, t; reverse = false)
     if sign(W.dt) * t > sign(W.dt) * W.t[end] ||
-       (sign(W.dt) * t < sign(W.dt) * W.t[1] && reverse) # Steps past W (forward time || backward time)
+            (sign(W.dt) * t < sign(W.dt) * W.t[1] && reverse) # Steps past W (forward time || backward time)
         if reverse
             dt = t - W.t[1]
         else
@@ -395,7 +479,7 @@ end
                 return copy(W.curW), nothing
             end
         elseif !(t isa Union{Rational, Integer}) &&
-               isapprox(t, W.t[i]; atol = 100eps(typeof(t)), rtol = 100eps(t))
+                isapprox(t, W.t[i]; atol = 100eps(typeof(t)), rtol = 100eps(t))
             if isinplace(W)
                 W.curW .= W.W[i]
             else
@@ -486,7 +570,7 @@ end
 
 @inline function interpolate!(out1, out2, W::NoiseProcess, u, p, t; reverse = false)
     if (sign(W.dt) * t > sign(W.dt) * W.t[end] && !reverse) ||
-       (sign(W.dt) * t < sign(W.dt) * W.t[1] && reverse) # Steps past W (forward time || backward time)
+            (sign(W.dt) * t < sign(W.dt) * W.t[1] && reverse) # Steps past W (forward time || backward time)
         if reverse
             dt = t - W.t[1]
         else
@@ -525,7 +609,7 @@ end
                 out2 .= W.Z[i]
             end
         elseif !(t isa Union{Rational, Integer}) &&
-               isapprox(t, W.t[i]; atol = 100eps(typeof(t)), rtol = 100eps(t))
+                isapprox(t, W.t[i]; atol = 100eps(typeof(t)), rtol = 100eps(t))
             out1 .= W.W[i]
             if W.Z !== nothing
                 out2 .= W.Z[i]
