@@ -1,6 +1,31 @@
-function DiffEqBase.__solve(prob::AbstractNoiseProblem,
+"""
+    solve(prob::AbstractNoiseProblem; dt, kwargs...)
+
+Solve a noise problem by simulating the noise process over the specified time span.
+
+## Arguments
+- `prob`: An `AbstractNoiseProblem` containing the noise process and time span
+- `dt`: The time step size (required, no default)
+
+## Keyword Arguments
+- `seed`: Random seed for reproducible results
+- Additional keyword arguments are passed to the underlying solver
+
+## Returns
+A `NoiseProcess` object containing the simulated noise trajectory.
+
+## Example
+```julia
+W = WienerProcess(0.0, 0.0, 1.0)
+prob = NoiseProblem(W, (0.0, 1.0))
+sol = solve(prob; dt = 0.01)
+```
+"""
+function DiffEqBase.__solve(
+        prob::AbstractNoiseProblem,
         args::Union{Nothing, SciMLBase.DEAlgorithm}...; dt = 0.0,
-        kwargs...)
+        kwargs...
+    )
     if dt == 0.0 || dt == nothing
         error("dt must be provided to simulate a noise process. Please pass dt=...")
     end
@@ -27,5 +52,5 @@ function DiffEqBase.__solve(prob::AbstractNoiseProblem,
             accept_step!(W, dt, nothing, nothing)
         end
     end
-    W
+    return W
 end
