@@ -12,12 +12,14 @@
     f!(du, u, p, t) = du .= 1.01 * u
     σ!(du, u, p, t) = du .= 0.87 * u
 
-    dt1 = tend / 1e3
+    dt1 = tend / 1.0e3
     seed = 100
     Random.seed!(seed)
     prob = SDEProblem(f!, σ!, u₀, trange)
-    sol = solve(prob, EulerHeun(), dt = dt1, adaptive = false, save_noise = true,
-        saveat = collect(trange[1]:dt1:trange[2]))
+    sol = solve(
+        prob, EulerHeun(), dt = dt1, adaptive = false, save_noise = true,
+        saveat = collect(trange[1]:dt1:trange[2])
+    )
 
     # choose a random interval
     interval = (0.35, 0.87)
@@ -29,18 +31,24 @@
     forwardnoise2 = DiffEqNoiseProcess.NoiseWrapper(sol.W, indx = idx1)
 
     cpsol = solve(
-        remake(prob, tspan = interval, u0 = sol(interval[1]),
-            noise = forwardnoise),
-        sol.alg, save_noise = false; dt = dt1)
+        remake(
+            prob, tspan = interval, u0 = sol(interval[1]),
+            noise = forwardnoise
+        ),
+        sol.alg, save_noise = false; dt = dt1
+    )
     cpsol2 = solve(
-        remake(prob, tspan = interval, u0 = sol(interval[1]),
-            noise = forwardnoise2),
-        sol.alg, save_noise = false; dt = dt1)
+        remake(
+            prob, tspan = interval, u0 = sol(interval[1]),
+            noise = forwardnoise2
+        ),
+        sol.alg, save_noise = false; dt = dt1
+    )
 
     sola = vcat(sol.u[idx1:idx2]...)
     cpsola = vcat(cpsol.u...)
     cpsol2a = vcat(cpsol2.u...)
 
-    @test isapprox(sola, cpsola, atol = 1e-10)
-    @test isapprox(sola, cpsol2a, atol = 1e-10)
+    @test isapprox(sola, cpsola, atol = 1.0e-10)
+    @test isapprox(sola, cpsol2a, atol = 1.0e-10)
 end
