@@ -1,4 +1,3 @@
-
 using Test, Pkg
 
 const GROUP = get(ENV, "GROUP", "All")
@@ -6,11 +5,12 @@ const GROUP = get(ENV, "GROUP", "All")
 function activate_gpu_env()
     Pkg.activate("gpu")
     Pkg.develop(PackageSpec(path = dirname(@__DIR__)))
-    Pkg.instantiate()
+    return Pkg.instantiate()
 end
 
 @time begin
     if GROUP == "All" || GROUP == "Core1"
+        include("explicit_imports_test.jl")
         include("interpolation_test.jl")
         include("RSwM1_test.jl")
         include("RSwM2_test.jl")
@@ -38,6 +38,7 @@ end
         include("BWT_test.jl")
         include("pcn_test.jl")
         include("savestep_test.jl")
+        include("simple_noise_bigfloat_test.jl")
     end
 
     if GROUP == "All" || GROUP == "Bridge"
